//#####################################################################
// Copyright 2021, Craig Schroeder, Tamar Shinar.
// This file is part of PhysBAM whose distribution is governed by the license contained in the accompanying file PHYSBAM_COPYRIGHT.txt.
//#####################################################################
//#include <Core/Arrays/ARRAYS_ND.h>
//#include <Core/Arrays/FACE_ARRAYS.h>
//#include <Core/Boundaries/BOUNDARY.h>
//#include <Core/Geometry_Particles/DEBUG_PARTICLES.h>
//#include <Core/Grids/CELL_ITERATOR.h>
//#include <Core/Grids/FACE_INDEX.h>
//#include <Core/Grids/FACE_RANGE_ITERATOR.h>
//#include <Core/Grids/GRID.h>
//#include <Core/Interpolation/CUBIC_INTERPOLATION_FACE.h>
//#include <Core/Interpolation/CUBIC_SPLINE_INTERPOLATION_FACE.h>
//#include <Core/Interpolation/DIV_FREE_BALSARA.h>
//#include <Core/Interpolation/DIV_FREE_INTERPOLATION.h>
//#include <Core/Interpolation/DIV_FREE_INTERPOLATION_C1.h>
//#include <Core/Interpolation/DIV_FREE_INTERPOLATION_C1_INTERP.h>
//#include <Core/Interpolation/DIV_FREE_INTERPOLATION_INTERP.h>
//#include <Core/Interpolation/GENERAL_INTERPOLATION_FACE.h>
#include <Core/Interpolation/INTERPOLATION_SPLINES.h>
//#include <Core/Interpolation/LINEAR_INTERPOLATION_FACE.h>
#include <Core/Log/LOG.h>
#include <Core/Parsing/PARSE_ARGS.h>
//#include <Core/Random_Numbers/RANDOM_NUMBERS.h>
//#include <Core/Seeding/POISSON_DISK.h>
#include <Core/Symbolics/STATIC_POLYNOMIAL.h>
#include <Core/Tensors/STATIC_TENSOR.h>
//#include <Core/Utilities/VIEWER_DIR.h>
//#include <Core/Vectors/VECTOR.h>
//#include <Core/Viewer/VIEWER_OUTPUT.h>
#include "VELOCITY_FIELDS.h"
#include <array>
#include <fstream>

using namespace PhysBAM;

typedef double T;

template<size_t r,size_t d>
void Dump_Spline(const char* name,const std::array<std::array<double,d>,r>& A)
{
    for(int i=0;i<r;i++)
    {
        STATIC_POLYNOMIAL<T,1,d> coeff;
        for(int j=0;j<d;j++)
            coeff.Set_Term({j},A[i][j]);
        LOG::printf("lprint(%s_%i=factor(identify(%.16P)));\n",name,i,coeff);
    }
}

#define D(ns,sp) Dump_Spline(#sp,ns::sp);

int main(int argc, char* argv[])
{
    PARSE_ARGS parse_args(argc,argv);
    int dim=2;
    parse_args.Add("-dim",&dim,"dim","dimension to test");
    parse_args.Parse(true);
    D(IS,B1);
    D(IS,B2);
    D(IS,B3);
    D(IS,C2);
    D(IS,C3);
    D(IS,C4);
    D(IS,D3);
    D(IS,D4);
    D(IS,D5);
    D(IS,F4);
    D(IS,F5);
    D(IS,G4);
    D(IS,G5);
    D(IS,H3);
    D(IS,H4);
    D(IS,I3);
    D(IS,J3);
    D(IS4,B2);
    D(IS4,I4);
    D(IS4,J4);
    
    return 0;
}

